# ISO3166 JSON data files <a name="TOP"></a>

* `iso3166-2.json` - JSON containing all country data from restcountries, as well as subdivision data.
* `iso3166-2-min.json` - minified JSON containing all country subdivision data.